@@ -57,7 +57,7 @@ from ansiblelint.config import (
     log_entries,
     options,
 )
-from ansiblelint.loaders import load_ignore_txt
+from ansiblelint.loaders import IgnoreRule, IgnoreRuleQualifier, load_ignore_txt
 from ansiblelint.output import (
     console,
     console_stderr,
@@ -218,7 +218,9 @@ def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) ->
 
     # pylint: enable=import-outside-toplevel
 
-    if Version(ruamel_safe_version) > Version(ruamel_yaml_version_str):
+    if Version(ruamel_safe_version) > Version(
+        ruamel_yaml_version_str
+    ):  # pragma: no cover
         _logger.warning(
             "We detected use of `--fix` feature with a buggy ruamel-yaml %s library instead of >=%s, upgrade it before reporting any bugs like dropped comments.",
             ruamel_yaml_version_str,
@@ -227,7 +229,7 @@ def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) ->
     acceptable_tags = {"all", "none", *rules.known_tags()}
     unknown_tags = set(options.write_list).difference(acceptable_tags)
 
-    if unknown_tags:
+    if unknown_tags:  # pragma: no cover
         _logger.error(
             "Found invalid value(s) (%s) for --fix arguments, must be one of: %s",
             ", ".join(unknown_tags),
@@ -270,6 +272,19 @@ def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) ->
         result.matches.pop(idx)
 
 
+# By default, matches ignored in .ansible-lint-ignore are treated
+# as warnings [1].  If the user explicitly adds a skip qualifier
+# to the rule, it is treated as skipped here and does not show up
+# even as a warning.
+# [1] https://github.com/ansible/ansible-lint/issues/3068
+def _rule_is_skipped(tag: str, rules: set[IgnoreRule]) -> bool:
+    for rule in rules:
+        if tag != rule.rule:
+            return False
+        return IgnoreRuleQualifier.SKIP in rule.qualifiers
+    return False
+
+
 # pylint: disable=too-many-locals,too-many-statements
 def main(argv: list[str] | None = None) -> int:
     """Linter CLI entry point."""
@@ -299,7 +314,7 @@ def main(argv: list[str] | None = None) -> int:
             msg += "[/]"
             console.print(msg)
             msg = get_version_warning()
-            if msg:
+            if msg:  # pragma: no cover
                 console.print(msg)
             support_banner()
             must_exit = True
@@ -312,7 +327,7 @@ def main(argv: list[str] | None = None) -> int:
         _logger.debug("Options: %s", options)
         _logger.debug("CWD: %s", Path.cwd())
 
-    for warn in warns:
+    for warn in warns:  # pragma: no cover
         _logger.warning(str(warn.message))
     warnings.resetwarnings()
 
@@ -334,7 +349,7 @@ def main(argv: list[str] | None = None) -> int:
         or options.nodeps
     )
 
-    if not skip_schema_update:
+    if not skip_schema_update:  # pragma: no cover
         # pylint: disable=import-outside-toplevel
         from ansiblelint.schemas.__main__ import refresh_schemas
 
@@ -374,21 +389,28 @@ def main(argv: list[str] | None = None) -> int:
 
     # Remove skip_list items from the result
     result.matches = [m for m in result.matches if m.tag not in app.options.skip_list]
-    # Mark matches as ignored inside ignore file
+    # load ignore file
     ignore_map = load_ignore_txt(options.ignore_file)
+    # prune qualified skips from ignore file
+    result.matches = [
+        m for m in result.matches if not _rule_is_skipped(m.tag, ignore_map[m.filename])
+    ]
+    # others entries are ignored
     for match in result.matches:
-        if match.tag in ignore_map[match.filename]:
+        if match.tag in [
+            i.rule for i in ignore_map[match.filename]
+        ]:  # pragma: no cover
             match.ignored = True
             _logger.debug("Ignored: %s", match)
 
-    if app.yamllint_config.incompatible:
+    if app.yamllint_config.incompatible:  # pragma: no cover
         _logger.log(
             level=logging.ERROR if options.write_list else logging.WARNING,
             msg=app.yamllint_config.incompatible,
         )
 
     if options.write_list:
-        if app.yamllint_config.incompatible:
+        if app.yamllint_config.incompatible:  # pragma: no cover
             sys.exit(RC.INVALID_CONFIG)
         fix(runtime_options=options, result=result, rules=rules)
 
@@ -485,7 +507,7 @@ def path_inject(own_location: str = "") -> None:
     # functioning or that is in fact the same version that was installed as
     # our dependency, but addressing this would be done by ansible-compat.
     for cmd in ("ansible",):
-        if not shutil.which(cmd):
+        if not shutil.which(cmd):  # pragma: no cover
             msg = f"Failed to find runtime dependency '{cmd}' in PATH"
             raise RuntimeError(msg)
 
